import { HttpClient, HttpEvent, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';
import { ArrayCollection } from 'json2entity';
import { IQueryCriteria } from './query/query-criteria.interface';
import { IHttpRequestOptions } from './http-request-options.interface';
export declare type TPartialEntity<T> = {
    [P in keyof T]?: T[P];
};
export declare abstract class ApiService<E> {
    protected resourceUri: string;
    protected resourceNestedUri: string;
    protected resourceKeyId: string;
    private urlApi;
    private targetEntity;
    private httpClient;
    constructor(http: HttpClient, targetEntity: E, urlApi: string);
    fetchById(id: number | string, queryCriteria?: ArrayCollection<IQueryCriteria>, options?: IHttpRequestOptions): Observable<E | HttpResponse<E> | HttpEvent<E>>;
    fetch(queryCriteria?: ArrayCollection<IQueryCriteria>, options?: IHttpRequestOptions): Observable<ArrayCollection<E> | HttpResponse<ArrayCollection<E>> | HttpEvent<ArrayCollection<E>>>;
    save(entity: E, options?: IHttpRequestOptions): Observable<E | HttpResponse<E> | HttpEvent<E>>;
    create(entity: E, options?: IHttpRequestOptions): Observable<E | HttpResponse<E> | HttpEvent<E>>;
    update(entity: E, options?: IHttpRequestOptions): Observable<E | HttpResponse<E> | HttpEvent<E>>;
    modify(id: string | number, data: TPartialEntity<E>, options?: IHttpRequestOptions): Observable<E | HttpResponse<E> | HttpEvent<E>>;
    delete(id: number | string, options?: IHttpRequestOptions): Observable<any | E | HttpResponse<E> | HttpEvent<E>>;
    exist(id?: number | string, options?: IHttpRequestOptions): Observable<any>;
    updateNestedResourceUri(uri: string): void;
    getResourceUri(): string;
    protected prepareEntity(jsonData: any): any;
    protected getUrl(id?: string | number, queryCriteria?: ArrayCollection<IQueryCriteria>): string;
    protected getQueryParameters(queryCriteria?: ArrayCollection<IQueryCriteria>): string;
    protected prepareOptions(options?: IHttpRequestOptions, queryCriteria?: ArrayCollection<IQueryCriteria>): IHttpRequestOptions;
}
